@@ -2,7 +2,6 @@
  * sequence.c - cleri sequence element.
  */
 #include <cleri/sequence.h>
-#include <cleri/node.inline.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -111,13 +110,6 @@ static cleri_node_t * sequence__parse(
     }
 
     parent->len += node->len;
-    if (cleri__children_add(&parent->children, node))
-    {
-        /* error occurred, reverse changes set mg_node to NULL */
-        pr->is_valid = -1;
-        parent->len -= node->len;
-        cleri__node_free(node);
-        node = NULL;
-    }
+    cleri__node_add(parent, node);
     return node;
 }
